@@ -25,26 +25,24 @@ class UpdateNodeRunModeRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateNodeRunMode')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ProjectEnv(self):
+	def get_ProjectEnv(self): # String
 		return self.get_body_params().get('ProjectEnv')
 
-	def set_ProjectEnv(self,ProjectEnv):
+	def set_ProjectEnv(self, ProjectEnv):  # String
 		self.add_body_params('ProjectEnv', ProjectEnv)
-
-	def get_SchedulerType(self):
+	def get_SchedulerType(self): # Integer
 		return self.get_body_params().get('SchedulerType')
 
-	def set_SchedulerType(self,SchedulerType):
+	def set_SchedulerType(self, SchedulerType):  # Integer
 		self.add_body_params('SchedulerType', SchedulerType)
-
-	def get_NodeId(self):
+	def get_NodeId(self): # Long
 		return self.get_body_params().get('NodeId')
 
-	def set_NodeId(self,NodeId):
-		self.add_body_params('NodeId', NodeId)
\ No newline at end of file
+	def set_NodeId(self, NodeId):  # Long
+		self.add_body_params('NodeId', NodeId)
